@@ -1,11 +1,12 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 """measure your JND in orientation using a staircase method"""
 
-from psychopy import core, visual, gui, data, misc, event
+from psychopy import core, visual, gui, data, event
+from psychopy.tools.filetools import fromFile, toFile
 import time, numpy
 
 try:#try to get a previous parameters file
-    expInfo = misc.fromFile('lastParams.pickle')
+    expInfo = fromFile('lastParams.pickle')
 except:#if not there then use a default set
     expInfo = {'observer':'jwp', 'refOrientation':0}
 dateStr = time.strftime("%b_%d_%H%M", time.localtime())#add the current time
@@ -13,7 +14,7 @@ dateStr = time.strftime("%b_%d_%H%M", time.localtime())#add the current time
 #present a dialogue to change params
 dlg = gui.DlgFromDict(expInfo, title='simple JND Exp', fixed=['date'])
 if dlg.OK:
-    misc.toFile('lastParams.pickle', expInfo)#save params to file for next time
+    toFile('lastParams.pickle', expInfo)#save params to file for next time
 else:
     core.quit()#the user hit cancel so exit
 
@@ -26,9 +27,9 @@ dataFile.write('targetSide	oriIncrement	correct\n')
 globalClock = core.Clock()#to keep track of time
 trialClock = core.Clock()#to keep track of time
 win = visual.Window([800,600],allowGUI=False, monitor='testMonitor', units='deg')
-foil = visual.PatchStim(win, sf=1, size=4, mask='gauss', ori=expInfo['refOrientation'])
-target = visual.PatchStim(win, sf=1,  size=4, mask='gauss', ori=expInfo['refOrientation'])
-fixation = visual.PatchStim(win, color='black', tex=None, mask='circle',size=0.2)
+foil = visual.GratingStim(win, sf=1, size=4, mask='gauss', ori=expInfo['refOrientation'])
+target = visual.GratingStim(win, sf=1,  size=4, mask='gauss', ori=expInfo['refOrientation'])
+fixation = visual.GratingStim(win, color='black', tex=None, mask='circle',size=0.2)
 message1 = visual.TextStim(win, pos=[0,+3],text='Hit a key when ready.')
 message2 = visual.TextStim(win, pos=[0,-3], text="Then press left or right to identify the %.1fdegree probe." %(expInfo['refOrientation']))
 
@@ -70,7 +71,7 @@ for thisIncrement in staircase: #will step through the staircase
 
     #get response
     thisResp=None
-    while thisResp==None:
+    while thisResp is None:
         allKeys=event.waitKeys()
         for thisKey in allKeys:
             if (thisKey=='left' and targetSide==-1) or (thisKey=='right' and targetSide==1):
@@ -82,7 +83,7 @@ for thisIncrement in staircase: #will step through the staircase
         event.clearEvents('mouse')#only really needed for pygame windows
 
     #add the data to the staircase so it can calculate the next level
-    staircase.addData(thisResp)
+    staircase.addResponse(thisResp)
     dataFile.write('%i	%.3f	%i\n' %(targetSide, thisIncrement, thisResp))
 
 #staircase has ended
