@@ -1,20 +1,18 @@
 from psychopy import visual, core, event
 
 win = visual.Window([800,600])
-mov = visual.MovieStim(win, 'jwpIntro.mov', size=[320,240],flipVert=False,
-                       flipHoriz=False,
-    loop=True)
+mov = visual.MovieStim(win, 'jwpIntro.mov', size=[320,240],
+                       flipVert=False, flipHoriz=False, loop=True)
 print 'orig movie size=[%i,%i]' %(mov.format.width, mov.format.height)
 print 'duration=%.2fs' %(mov.duration)
 globalClock = core.Clock()
 
 while mov.status != visual.FINISHED:
     mov.draw()
-    win.update()
-    for key in event.getKeys():
-        if key in ['escape','q']:
-            win.close()
-            core.quit()
+    win.flip()
+    if event.getKeys(keyList=['escape','q']):
+        win.close()
+        core.quit()
 
 core.quit()
 
