@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 from psychopy import visual, core, event
 
 #create a window to draw in
@@ -6,7 +6,7 @@ myWin = visual.Window((600,600), allowGUI=False,
                       monitor='testMonitor', units='deg')
 
 #INITIALISE SOME STIMULI
-myDotShape = visual.PatchStim(myWin, mask='gauss',sf=3)
+myDotShape = visual.GratingStim(myWin, mask='gauss',sf=3)
 dotPatch = visual.DotStim(myWin, color=[1,1,1],
                         dotLife=5, #lifetime of a dot in frames (if this is long density artefacts can occur in the stimulus)
                         signalDots='different', #are the signal and noise dots 'different' or 'same' popns (see Scase et al)
@@ -19,8 +19,8 @@ message = visual.TextStim(myWin,text='Hit Q to quit',
                                  
 trialClock = core.Clock()
 t = lastFPSupdate = 0
-dotPatch.setAutoDraw(True)#always draw
-message.setAutoDraw(True)#always draw
+dotPatch.autoDraw = True  #always draw
+message.autoDraw = True  #always draw
 
 while t<60:#quits after 20 secs
     t=trialClock.getTime()
@@ -31,4 +31,3 @@ while t<60:#quits after 20 secs
         if key in ['escape','q']:
             myWin.close()
             core.quit()
-            
\ No newline at end of file
