@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 """When you want to reveal an image gradually from behind a mask, 
 the tempting thing to do is to alter a stimulus mask using .setMask()
 
@@ -8,7 +8,8 @@ efficient way of doing this is to create an element array and alter the
 opacity of each element of the array to reveal what's behind it.
 
 """
-from psychopy import core, visual, event, misc
+from psychopy import core, visual, event
+from psychopy.tools.arraytools import createXYs
 import numpy
 
 #create a window to draw in
@@ -23,7 +24,7 @@ gabor = visual.GratingStim(myWin,tex='sin',
     sf=5)
 
 #create a grid of xy vals
-xys = misc.createXYs( numpy.linspace(-0.5,0.5,11) )#11 entries from -0.5 to 0.5 
+xys = createXYs( numpy.linspace(-0.5,0.5,11) )#11 entries from -0.5 to 0.5
 #create opacity for each square in mask
 opacs = numpy.ones(len(xys))#all opaque to start
 #create mask
@@ -41,20 +42,19 @@ numpy.random.shuffle(maskIndices)
 frameN=0
 while True:
     t=trialClock.getTime()
-    gabor.setOri(1,'+')#advance ori by 1 degree
+    gabor.ori += 1  #advance ori by 1 degree
     gabor.draw()
 
     #update mask b ymaking one element transparent
     if frameN<len(maskIndices):
         ii = maskIndices[frameN]#select the next index to make transparent
         opacs[ii]=0
-        mask.setOpacities(opacs)
+        mask.opacities = opacs
     mask.draw()
     
     myWin.flip()
     frameN+=1
     #handle key presses each frame
-    for keys in event.getKeys():
-        if keys in ['escape','q']:
-            myWin.close()
-            core.quit()
+    if event.getKeys(keyList=['escape','q']):
+        myWin.close()
+        core.quit()
