@@ -4,7 +4,7 @@ See http://www.photoresearch.com/
 --------
 """
 # Part of the PsychoPy library
-# Copyright (C) 2012 Jonathan Peirce
+# Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 from psychopy import logging
@@ -37,7 +37,7 @@ class PR650:
         Various messages are printed to the log regarding the function of this device,
         but to see them you need to set the printing of the log to the correct level::
 
-            from psychopy import log
+            from psychopy import logging
             logging.console.setLevel(logging.ERROR)#error messages only
             logging.console.setLevel(logging.INFO)#will give a little more info
             logging.console.setLevel(logging.DEBUG)#will export a log of all communications
@@ -212,11 +212,11 @@ class PR650:
             power=[[],[],[]]
             for n in range(nPoints):
                 #each entry in list is a string like this:
-                thisNm, thisR = string.split(rawR[n],',')
+                thisNm, thisR = rawR[n].split(',')
                 thisR = thisR.replace('\r\n','')
-                thisNm, thisG = string.split(rawG[n],',')
+                thisNm, thisG = rawG[n].split(',')
                 thisG = thisG.replace('\r\n','')
-                thisNm, thisB = string.split(rawB[n],',')
+                thisNm, thisB = rawB[n].split(',')
                 thisB = thisB.replace('\r\n','')
                 exec('nm.append(%s)' %thisNm)
                 exec('power[0].append(%s)' %thisR)
@@ -227,7 +227,7 @@ class PR650:
             power = []
             for n, point in enumerate(rawStr):
                 #each entry in list is a string like this:
-                thisNm, thisPower = string.split(point,',')
+                thisNm, thisPower = point.split(',')
                 nm.append(thisNm)
                 power.append(thisPower.replace('\r\n',''))
             if progDlg: progDlg.Update(n)
