@@ -39,9 +39,9 @@ perhaps one less than this.  < S. Simpson Note: These are 'not' GIL bound
 threads and therefore actually improve performance > """
 
 DATA_FILE_TITLE = "ioHub DataStore - Experiment Data File."
-FILE_VERSION = '0.8.0.2'
+FILE_VERSION = '0.8.1.1'
 SCHEMA_AUTHORS = 'Sol Simpson'
-SCHEMA_MODIFIED_DATE = 'May 4th, 2014'
+SCHEMA_MODIFIED_DATE = 'Dec 19th, 2014'
 
         
 class ioHubpyTablesFile():
@@ -81,11 +81,54 @@ class ioHubpyTablesFile():
         for event_cls_name,event_cls in event_class_dict.iteritems():
             if event_cls.IOHUB_DATA_TABLE:
                 event_table_label=event_cls.IOHUB_DATA_TABLE
-                if event_table_label not in self.TABLES:
-                    self.TABLES[event_table_label]=self.emrtFile.createTable(self._eventGroupMappings[event_table_label],eventTableLabel2ClassName(event_table_label),event_cls.NUMPY_DTYPE, title="%s Data"%(device_instance.__class__.__name__,),filters=dfilter.copy())
-                    self.flush()
-    
-                self.addClassMapping(event_cls,self.TABLES[event_table_label])
+                if event_table_label not in self.TABLES.keys():
+                    try:
+                        self.TABLES[event_table_label]=self.emrtFile.createTable(self._eventGroupMappings[event_table_label],eventTableLabel2ClassName(event_table_label),event_cls.NUMPY_DTYPE, title="%s Data"%(device_instance.__class__.__name__,),filters=dfilter.copy())
+                        self.flush()
+                        #print2err("----------- CREATED TABLES ENTRY ------------")
+                        #print2err("\tevent_cls: {0}".format(event_cls))
+                        #print2err("\tevent_cls_name: {0}".format(event_cls_name))
+                        #print2err("\tevent_table_label: {0}".format(event_table_label))
+                        #print2err("\teventTableLabel2ClassName: {0}".format(eventTableLabel2ClassName(event_table_label)))
+                        #print2err("\t_eventGroupMappings[event_table_label]: {0}".format(self._eventGroupMappings[event_table_label]))
+                        #print2err("----------------------------------------------")
+                    except NodeError:
+                        self.TABLES[event_table_label]=self._eventGroupMappings[event_table_label]._f_get_child(eventTableLabel2ClassName(event_table_label))# self.emrtFile.createTable(,eventTableLabel2ClassName(event_table_label),event_cls.NUMPY_DTYPE, title="%s Data"%(device_instance.__class__.__name__,),filters=dfilter.copy())
+                        #print2err("----------- USED EXISTING TABLE FOR TABLES ENTRY ------------")
+                        #print2err("\tevent_cls: {0}".format(event_cls))
+                        #print2err("\tevent_cls_name: {0}".format(event_cls_name))
+                        #print2err("\tevent_table_label: {0}".format(event_table_label))
+                        #print2err("\teventTableLabel2ClassName: {0}".format(eventTableLabel2ClassName(event_table_label)))
+                        #print2err("\t_eventGroupMappings[event_table_label]: {0}".format(self._eventGroupMappings[event_table_label]))
+                        #print2err("----------------------------------------------")
+
+                    except Exception, e:
+                        print2err("---------------ERROR------------------")
+                        print2err("Exception %s in iohub.datastore.updateDataStoreStructure:"%(e.__class__.__name__))
+                        print2err("\tevent_cls: {0}".format(event_cls))
+                        print2err("\tevent_cls_name: {0}".format(event_cls_name))
+                        print2err("\tevent_table_label: {0}".format(event_table_label))
+                        print2err("\teventTableLabel2ClassName: {0}".format(eventTableLabel2ClassName(event_table_label)))
+                        print2err("\t_eventGroupMappings[event_table_label]: {0}".format(self._eventGroupMappings[event_table_label]))
+                        print2err("\tException: {0}".format(e))
+                        print2err("--------------------------------------")
+
+                if self.TABLES.has_key(event_table_label):
+                        #print2err("---------------ADDING CLASS MAPPING------------------")
+                        #print2err("\tevent_cls: {0}".format(event_cls))
+                        #print2err("\tevent_cls_name: {0}".format(event_cls_name))
+                        #print2err("\tevent_table_label: {0}".format(event_table_label))
+                        #print2err("\teventTableLabel2ClassName: {0}".format(eventTableLabel2ClassName(event_table_label)))
+                        #print2err("\t_eventGroupMappings[event_table_label]: {0}".format(self._eventGroupMappings[event_table_label]))
+                        #print2err("----------------------------------------------")
+                        self.addClassMapping(event_cls, self.TABLES[event_table_label])
+                else:
+                        print2err("---- IOHUB.DATASTORE CANNOT ADD CLASS MAPPING ----")
+                        print2err("\t** TABLES missing key: {0}".format(event_table_label))
+                        print2err("\tevent_cls: {0}".format(event_cls))
+                        print2err("\tevent_cls_name: {0}".format(event_cls_name))
+                        print2err("\teventTableLabel2ClassName: {0}".format(eventTableLabel2ClassName(event_table_label)))
+                        print2err("----------------------------------------------")
 
 
     def loadTableMappings(self):
@@ -178,6 +221,12 @@ class ioHubpyTablesFile():
             # Just means the table for this event type has not been created as the event type is not being recorded
             pass
 
+        try:
+            self.TABLES['PSTBOX_BUTTON'] = self.emrtFile.root.data_collection.events.serial.PstBoxButtonEvent
+        except:
+            # Just means the table for this event type has not been created as the event type is not being recorded
+            pass
+
         try:
             self.TABLES['MONOCULAR_EYE_SAMPLE']=self.emrtFile.root.data_collection.events.eyetracker.MonocularEyeSampleEvent
         except:
@@ -278,6 +327,7 @@ class ioHubpyTablesFile():
         self._eventGroupMappings['DIGITAL_INPUT']=self.emrtFile.root.data_collection.events.mcu
         self._eventGroupMappings['SERIAL_INPUT']=self.emrtFile.root.data_collection.events.serial
         self._eventGroupMappings['SERIAL_BYTE_CHANGE']=self.emrtFile.root.data_collection.events.serial
+        self._eventGroupMappings['PSTBOX_BUTTON']=self.emrtFile.root.data_collection.events.serial
         self._eventGroupMappings['MESSAGE']=self.emrtFile.root.data_collection.events.experiment
         self._eventGroupMappings['LOG']=self.emrtFile.root.data_collection.events.experiment
         self._eventGroupMappings['MONOCULAR_EYE_SAMPLE']=self.emrtFile.root.data_collection.events.eyetracker
@@ -604,4 +654,4 @@ class EyeTrackerSessionConfiguration(IsDescription):
 class ApparatusSetupMetaData(IsDescription):
     app_setup_id = UInt32Col(pos=1)
     
-"""
\ No newline at end of file
+"""
