@@ -16,38 +16,45 @@ from ...constants import DeviceConstants, EventConstants
 import numpy as N
 getTime = Computer.getTime
 
+
 class Serial(Device):
     """
     A general purpose serial input interface device. Configuration options
     are used to define how the serial input data should be parsed, and what
     conditions create a serial input event to be generated.
     """
-    _bytesizes = {5: serial.FIVEBITS,
-                  6: serial.SIXBITS,
-                  7: serial.SEVENBITS,
-                  8: serial.EIGHTBITS,
-                  }
+    _bytesizes = {
+        5: serial.FIVEBITS,
+        6: serial.SIXBITS,
+        7: serial.SEVENBITS,
+        8: serial.EIGHTBITS,
+        }
 
-    _parities = {'NONE': serial.PARITY_NONE,
-                  'EVEN': serial.PARITY_EVEN,
-                  'ODD': serial.PARITY_ODD,
-                  'MARK': serial.PARITY_MARK,
-                  'SPACE': serial.PARITY_SPACE
-                  }
+    _parities = {
+        'NONE': serial.PARITY_NONE,
+        'EVEN': serial.PARITY_EVEN,
+        'ODD': serial.PARITY_ODD,
+        'MARK': serial.PARITY_MARK,
+        'SPACE': serial.PARITY_SPACE
+    }
 
-    _stopbits = {'ONE': serial.STOPBITS_ONE,
-                  'ONE_AND_HALF': serial.STOPBITS_ONE_POINT_FIVE,
-                  'TWO': serial.STOPBITS_TWO
-                  }
+    _stopbits = {
+        'ONE': serial.STOPBITS_ONE,
+        'ONE_AND_HALF': serial.STOPBITS_ONE_POINT_FIVE,
+        'TWO': serial.STOPBITS_TWO
+    }
 
     DEVICE_TIMEBASE_TO_SEC = 1.0
     _newDataTypes = [('port', N.str, 32), ('baud', N.str, 32),]
     EVENT_CLASS_NAMES = ['SerialInputEvent','SerialByteChangeEvent']
     DEVICE_TYPE_ID = DeviceConstants.SERIAL
     DEVICE_TYPE_STRING = "SERIAL"
-    _serial_slots = ['port', 'baud', 'bytesize', 'parity', 'stopbits', '_serial', '_timeout', '_rx_buffer',
-                  '_parser_config', '_parser_state', '_event_count',
-                  '_byte_diff_mode','_custom_parser','_custom_parser_kwargs']
+    _serial_slots = [
+        'port', 'baud', 'bytesize', 'parity', 'stopbits', '_serial',
+        '_timeout', '_rx_buffer', '_parser_config', '_parser_state',
+        '_event_count', '_byte_diff_mode', '_custom_parser',
+        '_custom_parser_kwargs'
+    ]
     __slots__ = [e for e in _serial_slots]
 
     def __init__(self, *args, **kwargs):
@@ -59,7 +66,11 @@ class Serial(Device):
             if pports:
                 self.port = pports[0]
                 if len(pports) > 1:
-                    print2err("Warning: Serial device port configuration set to 'auto'.\nMultiple serial ports found:\n", pports, "\n** Using port ", self.port)
+                    print2err(
+                        "Warning: Serial device port configuration set "
+                        "to 'auto'.\nMultiple serial ports found:\n",
+                        pports, "\n** Using port ", self.port
+                    )
         self.baud = self.getConfiguration().get('baud')
         self.bytesize = self._bytesizes[self.getConfiguration().get('bytesize')]
         self.parity = self._parities[self.getConfiguration().get('parity')]
@@ -110,7 +121,9 @@ class Serial(Device):
                 mod = importlib.import_module(mod_name)
                 self._custom_parser = getattr(mod, func_name)
             except:
-                print2err("ioHub Serial Device Error: could not load custom_parser function: ",custom_parser_func_str)
+                print2err(
+                    "ioHub Serial Device Error: could not load "
+                    "custom_parser function: ", custom_parser_func_str)
                 printExceptionDetailsToStdErr()
 
             if self._custom_parser:
@@ -151,7 +164,7 @@ class Serial(Device):
             available = [port[0] for port in list_ports.comports()]
 
         if len(available) < 1:
-            print2err('Error: unable to find any serial ports on the computer.')
+            print2err("Error: unable to find any serial ports on the computer.")
             return []
         return available
 
@@ -460,6 +473,246 @@ class Serial(Device):
         self.setConnectionState(False)
         Device._close(self)
 
+
+class Pstbox(Serial):
+    """
+    Provides convenient access to the PST Serial Response Box.
+    """
+    EVENT_CLASS_NAMES = ['PstboxButtonEvent',]
+    DEVICE_TYPE_ID = DeviceConstants.PSTBOX
+    DEVICE_TYPE_STRING = 'PSTBOX'
+    # Only add new attributes for the subclass, the device metaclass
+    # pulls them together.
+    _serial_slots = [
+        '_nlamps', '_lamp_state',
+        '_streaming_state', '_button_query_state', '_state',
+        '_button_bytes', '_nbuttons'
+    ]
+    __slots__ = [e for e in _serial_slots]
+
+    def __init__(self, *args, **kwargs):
+        Serial.__init__(self, *args, **kwargs)
+
+        self._nbuttons = 5
+        # Buttons 0--4, from left to right:
+        # [1, 2, 4, 8, 16]
+        self._button_bytes = 2**N.arange(self._nbuttons, dtype='uint8')
+
+        self._nlamps = 5
+        self._lamp_state = N.repeat(False, self._nlamps)
+        self._streaming_state = True
+        self._button_query_state = True
+
+        update_lamp_state = True
+        self._state = N.r_[
+            self._lamp_state, self._button_query_state, update_lamp_state,
+            self._streaming_state
+        ]
+
+        self._update_state()
+
+    def _update_state(self):
+        update_lamp_state = True
+
+        # `state` is an array of bools.
+        state = N.r_[
+            self._lamp_state, self._button_query_state, update_lamp_state,
+            self._streaming_state
+        ]
+
+        # Convert the new state into a bitmask, collapse it into a
+        # single byte and send it to the response box.
+        state_bits = (2**N.arange(9))[state]
+        self.write(chr(N.sum(state_bits)))
+
+        # Set the `update lamp` bit to LOW again.
+        state[6] = False
+        self._state = state
+
+    def getState(self):
+        """
+        Return the current state of the response box.
+
+        Returns
+        -------
+        array
+            An array of 8 boolean values will be returned, corresponding to
+            the following properties:
+            - state of lamp 0 (on/off)
+            - state of lamp 1 (on/off)
+            - state of lamp 2 (on/off)
+            - state of lamp 3 (on/off)
+            - state of lamp 4 (on/off)
+            - button query state (on/off)
+            - update lamp state (yes/no)
+            - streaming state (on/off)
+
+        See Also
+        --------
+        setState
+
+        """
+        return self._state
+
+    def getLampState(self):
+        """
+        Return the current state of the lamps.
+
+        Returns
+        -------
+        array
+            An array of 5 boolean values will be returned, corresponding to
+            the following properties:
+            - state of lamp 0 (on/off)
+            - state of lamp 1 (on/off)
+            - state of lamp 2 (on/off)
+            - state of lamp 3 (on/off)
+            - state of lamp 4 (on/off)
+
+        See Also
+        --------
+        setLampState
+
+        """
+        return self._lamp_state
+
+    def setLampState(self, state):
+        """
+        Change the state of the lamps (on/off).
+
+        Parameters
+        ----------
+        state : array_like
+            The requested lamp states, from left to right. `0` or `False`
+            means off, and `1` or `True` means on. This method expects
+            an array of 5 boolean values, each corresponding to the
+            following properties:
+            - state of lamp 0 (on/off)
+            - state of lamp 1 (on/off)
+            - state of lamp 2 (on/off)
+            - state of lamp 3 (on/off)
+            - state of lamp 4 (on/off)
+
+        See Also
+        --------
+        getLampState
+
+        """
+        if len(state) != self._nlamps:
+            raise ValueError('Please specify a number of states that is '
+                             'equal to the number of lamps on the '
+                             'response box.')
+
+        state = N.array(state).astype('bool')
+        self._lamp_state = state
+        self._update_state()
+
+    def getStreamingState(self):
+        """
+        Get the current streaming state.
+
+        Returns
+        -------
+        bool
+            `True` if the box is streaming data, and `False` otherwise.
+
+        See Also
+        --------
+        setStreamingState
+
+        """
+        return self._streaming_state
+
+    def setStreamingState(self, state):
+        """
+        Switch on or off streaming mode.
+
+        If streaming mode is disabled, the box will not send anything
+        to the computer.
+
+        Parameters
+        ----------
+        state : bool
+            ``True`` will enable streaming, ``False`` will disable it.
+
+        See Also
+        --------
+        getStreamingState
+
+        """
+        self._streaming_state = bool(state)
+        self._update_state()
+
+    def getButtonQueryState(self):
+        """
+        Get the current button query state.
+
+        If the box is not querying buttons, no button presses will
+        be reported.
+
+        Returns
+        -------
+        bool
+            `True` if the box is streaming data, and `False` otherwise.
+
+        See Also
+        --------
+        getButtonQueryState
+
+        """
+        return self._button_query_state
+
+    def setButtonQueryState(self, state):
+        """
+        Switch on or off button querying.
+
+        Parameters
+        ----------
+        state : bool
+            ``True`` will enable querying, ``False`` will disable it.
+
+        See Also
+        --------
+        getButtonQueryState
+
+        """
+        self._button_query_state = bool(state)
+        self._update_state()
+
+    def _createByteChangeSerialEvent(self, logged_time, read_time,
+                                     prev_byte, new_byte):
+        self._event_count += 1
+        confidence_interval = read_time - self._last_poll_time
+
+        prev_byte = ord(prev_byte)
+        new_byte = ord(new_byte)
+
+        try:
+            if new_byte != 0:  # Button was pressed
+                button = N.where(self._button_bytes == new_byte)[0][0]
+                button_event = 'press'
+            else:  # Button was released
+                button = N.where(self._button_bytes == prev_byte)[0][0]
+                button_event = 'release'
+        except:
+            # Handles when data rx does not match either N.where within the try
+            return
+        events = [
+            0, 0, 0, Computer._getNextEventID(),
+            EventConstants.PSTBOX_BUTTON,
+            read_time,
+            logged_time,
+            read_time,
+            confidence_interval,
+            0.0,
+            0,
+            self.port,
+            button,
+            button_event
+        ]
+        self._addNativeEventToBuffer(events)
+
+
 class SerialInputEvent(DeviceEvent):
     _newDataTypes = [
             ('port', N.str, 32),
@@ -473,6 +726,7 @@ class SerialInputEvent(DeviceEvent):
     def __init__(self, *args, **kwargs):
         DeviceEvent.__init__(self, *args, **kwargs)
 
+
 class SerialByteChangeEvent(DeviceEvent):
     _newDataTypes = [
             ('port', N.str, 32),
@@ -485,4 +739,24 @@ class SerialByteChangeEvent(DeviceEvent):
     __slots__ = [e[0] for e in _newDataTypes]
 
     def __init__(self, *args, **kwargs):
-        DeviceEvent.__init__(self, *args, **kwargs)
\ No newline at end of file
+        DeviceEvent.__init__(self, *args, **kwargs)
+
+
+class PstboxButtonEvent(DeviceEvent):
+    # Add new fields for PstboxButtonEvent
+    _newDataTypes = [
+        ('port', N.str, 32),  # could be needed to identify events
+                              # from >1 connected button box; if that is
+                              # ever supported.
+        ('button', N.uint8),
+        ('button_event', N.str, 7)
+    ]
+
+    EVENT_TYPE_ID = EventConstants.PSTBOX_BUTTON
+    EVENT_TYPE_STRING = 'PSTBOX_BUTTON'
+    IOHUB_DATA_TABLE = EVENT_TYPE_STRING    
+
+
+    __slots__ = [e[0] for e in _newDataTypes]
+    def __init__(self, *args, **kwargs):
+        DeviceEvent.__init__(self, *args, **kwargs)
