@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 
 # Part of the PsychoPy library
-# Copyright (C) 2014 Jonathan Peirce
+# Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 import wx
@@ -535,10 +535,10 @@ class MainFrame(wx.Frame):
         #insert values from new calib into GUI
         self.ctrlCalibDate.SetValue(
             monitors.strFromDate(self.currentMon.getCalibDate()))
-        self.ctrlScrDist.SetValue(str(self.currentMon.getDistance()))
-        self.ctrlScrWidth.SetValue(str(self.currentMon.getWidth()))
-        self.ctrlScrPixHoriz.SetValue(str(self.currentMon.currentCalib['sizePix'][0]))
-        self.ctrlScrPixVert.SetValue(str(self.currentMon.currentCalib['sizePix'][1]))
+        self.ctrlScrDist.SetValue(locale.str(self.currentMon.getDistance() or 0))
+        self.ctrlScrWidth.SetValue(locale.str(self.currentMon.getWidth() or 0))
+        self.ctrlScrPixHoriz.SetValue(locale.str(self.currentMon.currentCalib['sizePix'][0] or 0))
+        self.ctrlScrPixVert.SetValue(locale.str(self.currentMon.currentCalib['sizePix'][1] or 0))
         #self.ctrlScrGamma.SetValue(str(self.currentMon.getGamma()))
         self.ctrlCalibNotes.SetValue(self.currentMon.getNotes() or '')
         self.ctrlUseBits.SetValue(self.currentMon.getUseBits())
