@@ -3,7 +3,7 @@
 # To build simple dialogues etc. (requires pyqt4)
 #
 #  Part of the PsychoPy library
-# Copyright (C) 2014 Jonathan Peirce
+# Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 from PyQt4 import QtGui
@@ -278,7 +278,6 @@ class Dlg(QtGui.QDialog):
 
         :return: self.data
         """
-        QtGui.QDialog.show(self)
         return self.display()
 
     def exec_(self):
@@ -289,19 +288,20 @@ class Dlg(QtGui.QDialog):
         updated values coming from each of the input fields created.
         Otherwise, None is returned.
         """
+
         self.layout.addWidget(self.buttonBox, self.irow, 0, 1, 2)
 
         # Center Dialog on appropriate screen
-        # TODO: Check that this is working right, may not be vertically
-        desktop = QtGui.QDesktopWidget()
+        frameGm = self.frameGeometry()
+        desktop = QtGui.QApplication.desktop()
         qtscreen = self.screen
         if self.screen <= 0:
             qtscreen = desktop.primaryScreen()
-        screen_center = desktop.screenGeometry(qtscreen).center()
-        qr = self.frameGeometry()
-        self.move(screen_center.x() - qr.width() / 4,
-                  screen_center.y() - qr.height() / 4)
+        centerPoint = desktop.screenGeometry(qtscreen).center()
+        frameGm.moveCenter(centerPoint)
+        self.move(frameGm.topLeft())
 
+        QtGui.QDialog.show(self)
         self.raise_()
         self.activateWindow()
 
@@ -394,6 +394,7 @@ def fileSaveDlg(initFilePath="", initFileName="",
                   "shelved files (*.shelf)"
     global qtapp  # avoid recreating for every gui
     qtapp = ensureQtApp()
+
     r = QtGui.QFileDialog.getSaveFileName(parent=None,
                                           caption=prompt,
                                           directory=os.path.join(initFilePath,
@@ -596,7 +597,7 @@ if __name__ == '__main__':
              u"<br>"
              u"Written by: Dr. John Doe"
              u"<br>"
-             u"Created using <b>PsychoPy</b> © Copyright 2014, Jonathan Peirce")
+             u"Created using <b>PsychoPy</b> © Copyright 2015, Jonathan Peirce")
 
 
     # Restore full screen psychopy window
