@@ -3,7 +3,7 @@ import os, shutil
 import numpy
 
 from openpyxl.reader.excel import load_workbook
-from psychopy import data, misc
+from psychopy import data
 from psychopy.tests import utils
 from tempfile import mkdtemp
 
@@ -22,11 +22,11 @@ class TestXLSX:
         """Currently tests the contents of xslx file against known good example
         """
         conds = data.importConditions(os.path.join(fixturesPath, 'trialTypes.xlsx'))
-        trials = data.TrialHandler(trialList=conds, seed=100, nReps=2)
+        trials = data.TrialHandler(trialList=conds, seed=100, nReps=2, autoLog=False)
         responses=[1,1,None,3,2,3, 1,3,2,2,1,1]
         rts=[0.1,0.1,None,0.3,0.2,0.3, 0.1,0.3,0.2,0.2,0.1,0.1]
         for trialN, trial in enumerate(trials):
-            if responses[trialN]==None:
+            if responses[trialN] is None:
                 continue
             trials.addData('resp', responses[trialN])
             trials.addData('rt',rts[trialN])
@@ -46,7 +46,7 @@ def test_TrialTypeImport():
         trialXLSX = fromXLSX[trialN]
         assert trialXLSX.keys()==trialCSV.keys()
         for header in trialCSV.keys():
-            if trialXLSX[header]==None and numpy.isnan(trialCSV[header]):
+            if trialXLSX[header] is None and numpy.isnan(trialCSV[header]):
                 trialCSV[header]=None#this is ok
             if trialXLSX[header] != trialCSV[header]:
                 print header, trialCSV[header], trialXLSX[header]
