@@ -1,18 +1,16 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
 """Library for working with internet connections"""
 
 # Part of the PsychoPy library
-# Copyright (C) 2013 Jonathan Peirce
+# Copyright (C) 2015 Jonathan Peirce
 # Distributed under the terms of the GNU General Public License (GPL).
 
 import os, sys, time
 import hashlib, base64
 import httplib, mimetypes
 import urllib2, socket, re
-import shutil # for testing
-from tempfile import mkdtemp
 from psychopy import logging
 from psychopy.constants import PSYCHOPY_USERAGENT
 from psychopy import prefs
@@ -23,10 +21,6 @@ socket.setdefaulttimeout(TIMEOUT)
 global proxies
 proxies = None #if this is populated then it has been set up already
 
-# selector for tests and demos:
-SELECTOR_FOR_TEST_UPLOAD = 'http://upload.psychopy.org/test/up.php'
-BASIC_AUTH_CREDENTIALS = 'psychopy:open-sourc-ami'
-
 
 class NoInternetAccessError(StandardError):
     """An internet connection is required but not available
@@ -40,7 +34,7 @@ def haveInternetAccess(forceCheck=False):
     If forceCheck is False, will rely on a cached value if possible.
     """
     global haveInternet
-    if forceCheck or haveInternet not in [True, False]:
+    if forceCheck or haveInternet is None:
         # try to connect to a high-availability site
         sites = ["http://www.google.com/", "http://www.opendns.com/"]
         for wait in [0.3, 0.7]:  # try to be quick first
@@ -49,7 +43,7 @@ def haveInternetAccess(forceCheck=False):
                     urllib2.urlopen(site, timeout=wait)
                     haveInternet = True  # cache
                     return True  # one success is good enough
-                except urllib2.URLError:
+                except:  # urllib2.URLError:  # socket.timeout() was happening to some people some of the time
                     pass
         else:
             haveInternet = False
@@ -64,7 +58,7 @@ def requireInternetAccess(forceCheck=False):
         raise NoInternetAccessError(msg)
     return True
 
-def testProxy(handler, URL=None):
+def tryProxy(handler, URL=None):
     """
     Test whether we can connect to a URL with the current proxy settings.
 
@@ -141,7 +135,7 @@ def getWpadFiles():
         pacURLs.append("http://wpad."+domain+"/wpad.dat")
     return list(set(pacURLs)) # remove redundant ones
 
-def proxyFromPacFiles(pacURLs=[], URL=None):
+def proxyFromPacFiles(pacURLs=[], URL=None, log=True):
     """Attempts to locate and setup a valid proxy server from pac file URLs
 
     :Parameters:
@@ -168,11 +162,13 @@ def proxyFromPacFiles(pacURLs=[], URL=None):
         pacURLs = getWpadFiles()
         #for each file search for valid urls and test them as proxies
     for thisPacURL in pacURLs:
-        logging.debug('proxyFromPacFiles is searching file:\n  %s' %thisPacURL)
+        if log:
+            logging.debug('proxyFromPacFiles is searching file:\n  %s' %thisPacURL)
         try:
             response = urllib2.urlopen(thisPacURL, timeout=2)
         except urllib2.URLError:
-            logging.debug("Failed to find PAC URL '%s' " %thisPacURL)
+            if log:
+                logging.debug("Failed to find PAC URL '%s' " %thisPacURL)
             continue
         pacStr = response.read()
         #find the candidate PROXY strings (valid URLS), numeric and non-numeric:
@@ -180,13 +176,14 @@ def proxyFromPacFiles(pacURLs=[], URL=None):
         for thisPoss in possProxies:
             proxUrl = 'http://' + thisPoss
             handler=urllib2.ProxyHandler({'http':proxUrl})
-            if testProxy(handler)==True:
-                logging.debug('successfully loaded: %s' %proxUrl)
+            if tryProxy(handler)==True:
+                if log:
+                    logging.debug('successfully loaded: %s' %proxUrl)
                 urllib2.install_opener(urllib2.build_opener(handler))
                 return handler
     return False
 
-def setupProxy():
+def setupProxy(log=True):
     """Set up the urllib proxy if possible.
 
      The function will use the following methods in order to try and determine proxies:
@@ -206,30 +203,35 @@ def setupProxy():
     global proxies
     #try doing nothing
     proxies=urllib2.ProxyHandler(urllib2.getproxies())
-    if testProxy(proxies) is True:
-        logging.debug("Using standard urllib2 (static proxy or no proxy required)")
+    if tryProxy(proxies) is True:
+        if log:
+            logging.debug("Using standard urllib2 (static proxy or no proxy required)")
         urllib2.install_opener(urllib2.build_opener(proxies))#this will now be used globally for ALL urllib2 opening
         return 1
 
     #try doing what we did last time
     if len(prefs.connections['proxy'])>0:
         proxies=urllib2.ProxyHandler({'http': prefs.connections['proxy']})
-        if testProxy(proxies) is True:
-            logging.debug('Using %s (from prefs)' %(prefs.connections['proxy']))
+        if tryProxy(proxies) is True:
+            if log:
+                logging.debug('Using %s (from prefs)' %(prefs.connections['proxy']))
             urllib2.install_opener(urllib2.build_opener(proxies))#this will now be used globally for ALL urllib2 opening
             return 1
         else:
-            logging.debug("Found a previous proxy but it didn't work")
+            if log:
+                logging.debug("Found a previous proxy but it didn't work")
 
     #try finding/using a proxy.pac file
     pacURLs=getPacFiles()
-    logging.debug("Found proxy PAC files: %s" %pacURLs)
+    if log:
+        logging.debug("Found proxy PAC files: %s" %pacURLs)
     proxies=proxyFromPacFiles(pacURLs) # installs opener, if successful
     if proxies and hasattr(proxies, 'proxies') and len(proxies.proxies['http'])>0:
         #save that proxy for future
         prefs.connections['proxy']=proxies.proxies['http']
         prefs.saveUserPrefs()
-        logging.debug('Using %s (from proxy PAC file)' %(prefs.connections['proxy']))
+        if log:
+            logging.debug('Using %s (from proxy PAC file)' %(prefs.connections['proxy']))
         return 1
 
     #try finding/using 'auto-detect proxy'
@@ -239,7 +241,8 @@ def setupProxy():
         #save that proxy for future
         prefs.connections['proxy']=proxies.proxies['http']
         prefs.saveUserPrefs()
-        logging.debug('Using %s (from proxy auto-detect)' %(prefs.connections['proxy']))
+        if log:
+            logging.debug('Using %s (from proxy auto-detect)' %(prefs.connections['proxy']))
         return 1
 
     proxies=0
@@ -324,7 +327,7 @@ def _post_multipart(host, selector, fields, files, encoding='utf-8', timeout=TIM
 
     ## end of http://code.activestate.com/recipes/146306/ }}}
 
-def upload(selector, filename, basicAuth=None, host=None, https=False):
+def upload(selector, filename, basicAuth=None, host=None, https=False, log=True):
     """Upload a local file over the internet to a configured http server.
 
     This method handshakes with a php script on a remote server to transfer a local
@@ -392,7 +395,7 @@ def upload(selector, filename, basicAuth=None, host=None, https=False):
 
     Author: Jeremy R. Gray, 2012
     """
-    
+
     requireInternetAccess()  # needed to upload over http
 
     fields = [('name', 'PsychoPy_upload'), ('type', 'file')]
@@ -401,12 +404,13 @@ def upload(selector, filename, basicAuth=None, host=None, https=False):
         raise ValueError('upload: need a selector, http://<host>/path/to/up.php')
     if not host:
         host = selector.split('/')[2]
-        logging.info('upload: host extracted from selector = %s' % host)
+        if log:
+            logging.info('upload: host extracted from selector = %s' % host)
     if selector.startswith('https'):
         if https is not True:
             logging.error('upload: https not explicitly requested. use https=True to proceed anyway (see API for security caveats).')
             raise ValueError('upload: https not fully supported (see API for caveats and usage), exiting.')
-        else:
+        elif log:
             logging.exp('upload: https requested; note that security is not fully assured (see API)')
     elif https:
         msg = 'upload: to use https, the selector URL must start with "https"'
@@ -419,7 +423,8 @@ def upload(selector, filename, basicAuth=None, host=None, https=False):
     file = [('file_1', filename, contents)]
 
     # initiate the POST:
-    logging.exp('upload: uploading file %s to %s' % (os.path.abspath(filename), selector))
+    if log:
+        logging.exp('upload: uploading file %s to %s' % (os.path.abspath(filename), selector))
     try:
         status, reason, result = _post_multipart(host, selector, fields, file,
                                                  basicAuth=basicAuth, https=https)
@@ -454,71 +459,8 @@ def upload(selector, filename, basicAuth=None, host=None, https=False):
         logging.error('upload: ' + outcome[:102])
     else:
         if outcome.startswith('success'):
-            logging.info('upload: ' + outcome[:102])
+            if log:
+                logging.info('upload: ' + outcome[:102])
         else:
             logging.error('upload: ' + outcome[:102])
     return outcome
-
-def _test_upload():
-    def _upload(stuff):
-        """assumes that SELECTOR_FOR_TEST_UPLOAD is a configured http server
-        """
-        selector = SELECTOR_FOR_TEST_UPLOAD
-        basicAuth = BASIC_AUTH_CREDENTIALS
-
-        # make a tmp dir just for testing:
-        tmp = mkdtemp()
-        filename = 'test.txt'
-        tmp_filename = os.path.join(tmp, filename)
-        f = open(tmp_filename, 'w+')
-        f.write(stuff)
-        f.close()
-
-        # get local sha256 before cleanup:
-        digest = hashlib.sha256()
-        digest.update(open(tmp_filename).read())
-        dgst = digest.hexdigest()
-
-        # upload:
-        status = upload(selector, tmp_filename, basicAuth)
-        shutil.rmtree(tmp) # cleanup; do before asserts
-
-        # test
-        good_upload = True
-        disgest_match = False
-        if not status.startswith('success'):
-            good_upload = False
-        elif status.find(dgst) > -1:
-            logging.exp('digests match')
-            digest_match = True
-        else:
-            logging.error('digest mismatch')
-
-        logging.flush()
-        assert good_upload # remote server FAILED to report success
-        assert digest_match # sha256 mismatch local vs remote file
-
-        return int(status.split()[3]) # bytes
-
-    # test upload: normal text, binary:
-    msg = PSYCHOPY_USERAGENT # can be anything
-    print 'text:   '
-    bytes = _upload(msg) #normal text
-    assert (bytes == len(msg)) # FAILED to report len() bytes
-
-    print 'binary: '
-    digest = hashlib.sha256()  # to get binary, 256 bits
-    digest.update(msg)
-    bytes = _upload(digest.digest())
-    assert (bytes == 32) # FAILED to report 32 bytes for a 256-bit binary file (= odd if digests match)
-    logging.exp('binary-file byte-counts match')
-
-if __name__ == '__main__':
-    """unit-tests for this module"""
-    logging.console.setLevel(logging.DEBUG)
-
-    t0=time.time()
-    print setupProxy()
-    print 'setup proxy took %.2fs' %(time.time()-t0)
-
-    _test_upload()
\ No newline at end of file
