@@ -49,7 +49,7 @@ setup(app=['psychopy/app/psychopyApp.py'],
                                 'coverage',#for unit testing
                                 'serial','IPython',
                                 'egi','labjack','pylink',#handy external science interfaces
-                                'pyxid','pycrsltd',
+                                'pyxid',
                                 #'PIL','Image',
                                 'objc','Quartz','AppKit','QTKit','Cocoa','Foundation','CoreFoundation',
                                 'pyolib',
